@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct ElixirConfig<'a> {
     pub format: &'a str,
@@ -14,9 +18,9 @@ pub struct ElixirConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for ElixirConfig<'a> {
+impl Default for ElixirConfig<'_> {
     fn default() -> Self {
-        ElixirConfig {
+        Self {
             format: "via [$symbol($version \\(OTP $otp_version\\) )]($style)",
             version_format: "v${raw}",
             symbol: "💧 ",
