@@ -18,9 +18,9 @@ pub struct ErlangConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for ErlangConfig<'a> {
+impl Default for ErlangConfig<'_> {
     fn default() -> Self {
-        ErlangConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: " ",
