@@ -16,9 +16,9 @@ pub struct FossilBranchConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for FossilBranchConfig<'a> {
+impl Default for FossilBranchConfig<'_> {
     fn default() -> Self {
-        FossilBranchConfig {
+        Self {
             format: "on [$symbol$branch]($style) ",
             symbol: " ",
             style: "bold purple",
