@@ -13,16 +13,18 @@ pub struct GitMetricsConfig<'a> {
     pub only_nonzero_diffs: bool,
     pub format: &'a str,
     pub disabled: bool,
+    pub ignore_submodules: bool,
 }
 
-impl<'a> Default for GitMetricsConfig<'a> {
+impl Default for GitMetricsConfig<'_> {
     fn default() -> Self {
-        GitMetricsConfig {
+        Self {
             added_style: "bold green",
             deleted_style: "bold red",
             only_nonzero_diffs: true,
             format: "([+$added]($added_style) )([-$deleted]($deleted_style) )",
             disabled: true,
+            ignore_submodules: false,
         }
     }
 }
