@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct GitStateConfig<'a> {
     pub rebase: &'a str,
@@ -16,9 +20,9 @@ pub struct GitStateConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for GitStateConfig<'a> {
+impl Default for GitStateConfig<'_> {
     fn default() -> Self {
-        GitStateConfig {
+        Self {
             rebase: "REBASING",
             merge: "MERGING",
             revert: "REVERTING",
