@@ -18,9 +18,9 @@ pub struct GleamConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for GleamConfig<'a> {
+impl Default for GleamConfig<'_> {
     fn default() -> Self {
-        GleamConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "⭐ ",
