@@ -13,19 +13,21 @@ pub struct GoConfig<'a> {
     pub symbol: &'a str,
     pub style: &'a str,
     pub disabled: bool,
+    pub not_capable_style: &'a str,
     pub detect_extensions: Vec<&'a str>,
     pub detect_files: Vec<&'a str>,
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for GoConfig<'a> {
+impl Default for GoConfig<'_> {
     fn default() -> Self {
-        GoConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "🐹 ",
             style: "bold cyan",
             disabled: false,
+            not_capable_style: "bold red",
             detect_extensions: vec!["go"],
             detect_files: vec![
                 "go.mod",
