@@ -18,9 +18,9 @@ pub struct HaskellConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for HaskellConfig<'a> {
+impl Default for HaskellConfig<'_> {
     fn default() -> Self {
-        HaskellConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "λ ",
