@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct JobsConfig<'a> {
     pub threshold: i64,
@@ -13,9 +17,9 @@ pub struct JobsConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for JobsConfig<'a> {
+impl Default for JobsConfig<'_> {
     fn default() -> Self {
-        JobsConfig {
+        Self {
             threshold: 1,
             symbol_threshold: 1,
             number_threshold: 2,
