@@ -20,9 +20,9 @@ pub struct OCamlConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for OCamlConfig<'a> {
+impl Default for OCamlConfig<'_> {
     fn default() -> Self {
-        OCamlConfig {
+        Self {
             format: "via [$symbol($version )(\\($switch_indicator$switch_name\\) )]($style)",
             version_format: "v${raw}",
             global_switch_indicator: "",
