@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct PackageConfig<'a> {
     pub format: &'a str,
@@ -12,9 +16,9 @@ pub struct PackageConfig<'a> {
     pub version_format: &'a str,
 }
 
-impl<'a> Default for PackageConfig<'a> {
+impl Default for PackageConfig<'_> {
     fn default() -> Self {
-        PackageConfig {
+        Self {
             format: "is [$symbol$version]($style) ",
             symbol: "📦 ",
             style: "208 bold",
