@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct PulumiConfig<'a> {
     pub format: &'a str,
@@ -12,9 +16,9 @@ pub struct PulumiConfig<'a> {
     pub search_upwards: bool,
 }
 
-impl<'a> Default for PulumiConfig<'a> {
+impl Default for PulumiConfig<'_> {
     fn default() -> Self {
-        PulumiConfig {
+        Self {
             format: "via [$symbol($username@)$stack]($style) ",
             version_format: "v${raw}",
             symbol: " ",
