@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct RubyConfig<'a> {
     pub format: &'a str,
@@ -15,9 +19,9 @@ pub struct RubyConfig<'a> {
     pub detect_variables: Vec<&'a str>,
 }
 
-impl<'a> Default for RubyConfig<'a> {
+impl Default for RubyConfig<'_> {
     fn default() -> Self {
-        RubyConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "💎 ",
