@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct TerraformConfig<'a> {
     pub format: &'a str,
@@ -12,11 +16,12 @@ pub struct TerraformConfig<'a> {
     pub detect_extensions: Vec<&'a str>,
     pub detect_files: Vec<&'a str>,
     pub detect_folders: Vec<&'a str>,
+    pub commands: Vec<Vec<&'a str>>,
 }
 
-impl<'a> Default for TerraformConfig<'a> {
+impl Default for TerraformConfig<'_> {
     fn default() -> Self {
-        TerraformConfig {
+        Self {
             format: "via [$symbol$workspace]($style) ",
             version_format: "v${raw}",
             symbol: "💠 ",
@@ -25,6 +30,12 @@ impl<'a> Default for TerraformConfig<'a> {
             detect_extensions: vec!["tf", "tfplan", "tfstate"],
             detect_files: vec![],
             detect_folders: vec![".terraform"],
+            commands: vec![
+                // terraform is usually `terraform`
+                vec!["terraform", "version"],
+                // but for opentofu users, it'll be `tofu`
+                vec!["tofu", "version"],
+            ],
         }
     }
 }
