@@ -18,9 +18,9 @@ pub struct TypstConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for TypstConfig<'a> {
+impl Default for TypstConfig<'_> {
     fn default() -> Self {
-        TypstConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "t ",
