@@ -18,9 +18,9 @@ pub struct VagrantConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for VagrantConfig<'a> {
+impl Default for VagrantConfig<'_> {
     fn default() -> Self {
-        VagrantConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "⍱ ",
