@@ -25,7 +25,8 @@ use std::num::ParseIntError;
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
 use std::string::String;
-use std::sync::OnceLock;
+use std::sync::{Arc, OnceLock, mpsc};
+use std::thread;
 use std::time::{Duration, Instant};
 use terminal_size::terminal_size;
 
@@ -109,7 +110,7 @@ impl<'a> Context<'a> {
             .or_else(|| env::var("PWD").map(PathBuf::from).ok())
             .unwrap_or_else(|| path.clone());
 
-        Context::new_with_shell_and_path(
+        Self::new_with_shell_and_path(
             arguments,
             shell,
             target,
@@ -128,7 +129,7 @@ impl<'a> Context<'a> {
         logical_path: PathBuf,
         env: Env<'a>,
     ) -> Self {
-        let config = StarshipConfig::initialize(&get_config_path_os(&env));
+        let config = StarshipConfig::initialize(get_config_path_os(&env).as_deref());
 
         // If the vector is zero-length, we should pretend that we didn't get a
         // pipestatus at all (since this is the input `--pipestatus=""`)
@@ -162,7 +163,7 @@ impl<'a> Context<'a> {
 
         let width = properties.terminal_width;
 
-        Context {
+        Self {
             config,
             properties,
             current_dir,
@@ -220,7 +221,7 @@ impl<'a> Context<'a> {
     }
 
     /// Create a new module
-    pub fn new_module(&self, name: &str) -> Module {
+    pub fn new_module(&self, name: &str) -> Module<'_> {
         let config = self.config.get_module_config(name);
         let desc = modules::description(name);
 
@@ -265,6 +266,28 @@ impl<'a> Context<'a> {
         iter.peek().is_none() || iter.any(|env_var| self.get_env(env_var).is_some())
     }
 
+    /// Returns an enum indicating if `detect_env_vars` contains negated or non-negated variables
+    pub fn detect_env_vars2(&'a self, env_vars: &'a [&'a str]) -> Detected {
+        if env_vars.is_empty() {
+            return Detected::Empty;
+        }
+
+        if self.has_negated_env_var(env_vars) {
+            return Detected::Negated;
+        }
+
+        let mut iter = env_vars
+            .iter()
+            .filter(|env_var| !env_var.starts_with('!'))
+            .peekable();
+
+        if iter.any(|env_var| self.get_env(env_var).is_some()) {
+            Detected::Yes
+        } else {
+            Detected::No
+        }
+    }
+
     // returns a new ScanDir struct with reference to current dir_files of context
     // see ScanDir for methods
     pub fn try_begin_scan(&'a self) -> Option<ScanDir<'a>> {
@@ -411,11 +434,7 @@ impl<'a> Context<'a> {
         cmd: T,
         args: &[U],
     ) -> Option<CommandOutput> {
-        log::trace!(
-            "Executing command {:?} with args {:?} from context",
-            cmd,
-            args
-        );
+        log::trace!("Executing command {cmd:?} with args {args:?} from context");
         #[cfg(test)]
         {
             let command = crate::utils::display_command(&cmd, args);
@@ -437,7 +456,7 @@ impl<'a> Context<'a> {
     }
 
     /// Attempt to execute several commands with `exec_cmd`, return the results of the first that works
-    pub fn exec_cmds_return_first(&self, commands: Vec<Vec<&str>>) -> Option<CommandOutput> {
+    pub fn exec_cmds_return_first(&self, commands: &[Vec<&str>]) -> Option<CommandOutput> {
         commands
             .iter()
             .find_map(|attempt| self.exec_cmd(attempt[0], &attempt[1..]))
@@ -462,10 +481,22 @@ impl<'a> Context<'a> {
 
 impl Default for Context<'_> {
     fn default() -> Self {
-        Context::new(Default::default(), Target::Main)
+        Self::new(Default::default(), Target::Main)
     }
 }
 
+#[derive(Debug, PartialEq, Eq)]
+pub enum Detected {
+    /// `detect_env_vars` was empty.
+    Empty,
+    /// A negated variable was found.
+    Negated,
+    /// A non-negated variable was found.
+    Yes,
+    /// No non-negated variables were found.
+    No,
+}
+
 fn home_dir(env: &Env) -> Option<PathBuf> {
     if cfg!(test) {
         if let Some(home) = env.get_env("HOME") {
@@ -505,61 +536,100 @@ impl DirContents {
         timeout: Duration,
         follow_symlinks: bool,
     ) -> Result<Self, std::io::Error> {
+        let _ = fs::read_dir(base)?; // Early return if invalid base
+
         let start = Instant::now();
+        let mut remaining_time = timeout;
 
         let mut folders: HashSet<PathBuf> = HashSet::new();
         let mut files: HashSet<PathBuf> = HashSet::new();
         let mut file_names: HashSet<String> = HashSet::new();
         let mut extensions: HashSet<String> = HashSet::new();
 
-        fs::read_dir(base)?
-            .enumerate()
-            .take_while(|(n, _)| {
-                cfg!(test) // ignore timeout during tests
-                || n & 0xFF != 0 // only check timeout once every 2^8 entries
-                || start.elapsed() < timeout
-            })
-            .filter_map(|(_, entry)| entry.ok())
-            .for_each(|entry| {
-                let path = PathBuf::from(entry.path().strip_prefix(base).unwrap());
+        let base_path = base;
+        let base = Arc::from(base);
+        let (tx, rx) = mpsc::channel();
 
-                let is_dir = match follow_symlinks {
-                    true => entry.path().is_dir(),
-                    false => fs::symlink_metadata(entry.path())
-                        .map(|m| m.is_dir())
-                        .unwrap_or(false),
-                };
+        {
+            let worker = move || {
+                let dir_iter = fs::read_dir(base).unwrap();
+                let _ = dir_iter
+                    .filter_map(|entry| entry.ok())
+                    .try_for_each(|entry| tx.send(entry));
+            };
 
-                if is_dir {
-                    folders.insert(path);
-                } else {
-                    if !path.to_string_lossy().starts_with('.') {
-                        // Extract the file extensions (yes, that's plural) from a filename.
-                        // Why plural? Consider the case of foo.tar.gz. It's a compressed
-                        // tarball (tar.gz), and it's a gzipped file (gz). We should be able
-                        // to match both.
+            let _ = thread::Builder::new()
+                .name("from_path_with_timeout worker".into())
+                .spawn(worker)?;
+        }
 
-                        // find the minimal extension on a file. ie, the gz in foo.tar.gz
-                        // NB the .to_string_lossy().to_string() here looks weird but is
-                        // required to convert it from a Cow.
-                        path.extension()
-                            .map(|ext| extensions.insert(ext.to_string_lossy().to_string()));
+        loop {
+            // TODO: use `recv_deadline` instead once stable
+            let msg = if cfg!(test) {
+                // recv() errors out only when the corresponding sender closes.
+                // See mpsc::RecvError.
+                rx.recv().map_err(|_| mpsc::RecvTimeoutError::Disconnected)
+            } else {
+                rx.recv_timeout(remaining_time)
+            };
+            match msg {
+                Ok(entry) => {
+                    let path = PathBuf::from(entry.path().strip_prefix(base_path).unwrap());
 
-                        // find the full extension on a file. ie, the tar.gz in foo.tar.gz
-                        path.file_name().map(|file_name| {
-                            file_name
-                                .to_string_lossy()
-                                .split_once('.')
-                                .map(|(_, after)| extensions.insert(after.to_string()))
-                        });
+                    let is_dir = match follow_symlinks {
+                        true => entry.path().is_dir(),
+                        false => fs::symlink_metadata(entry.path())
+                            .map(|m| m.is_dir())
+                            .unwrap_or(false),
+                    };
+
+                    if is_dir {
+                        folders.insert(path);
+                    } else {
+                        if !path.to_string_lossy().starts_with('.') {
+                            // Extract the file extensions (yes, that's plural) from a filename.
+                            // Why plural? Consider the case of foo.tar.gz. It's a compressed
+                            // tarball (tar.gz), and it's a gzipped file (gz). We should be able
+                            // to match both.
+
+                            // find the minimal extension on a file. ie, the gz in foo.tar.gz
+                            // NB the .to_string_lossy().to_string() here looks weird but is
+                            // required to convert it from a Cow.
+                            path.extension()
+                                .map(|ext| extensions.insert(ext.to_string_lossy().to_string()));
+
+                            // find the full extension on a file. ie, the tar.gz in foo.tar.gz
+                            path.file_name().map(|file_name| {
+                                file_name
+                                    .to_string_lossy()
+                                    .split_once('.')
+                                    .map(|(_, after)| extensions.insert(after.to_string()))
+                            });
+                        }
+                        if let Some(file_name) = path.file_name() {
+                            // this .to_string_lossy().to_string() is also required
+                            file_names.insert(file_name.to_string_lossy().to_string());
+                        }
+                        files.insert(path);
                     }
-                    if let Some(file_name) = path.file_name() {
-                        // this .to_string_lossy().to_string() is also required
-                        file_names.insert(file_name.to_string_lossy().to_string());
+
+                    if remaining_time <= Duration::from_millis(0) && rx.try_recv().is_err() {
+                        // Timed-out, and rx has been drained.
+                        log::warn!("from_path_with_timeout has timed-out!");
+                        break;
                     }
-                    files.insert(path);
+
+                    // recv_deadline is nightly: calculate the remaining time instead.
+                    // after loop break to give chance to drain rx
+                    remaining_time =
+                        timeout.saturating_sub(Instant::now().saturating_duration_since(start));
                 }
-            });
+                Err(_) => {
+                    // Timeout or Disconnected occurred
+                    break;
+                }
+            }
+        }
 
         log::trace!(
             "Building HashSets of directory files, folders and extensions took {:?}",
@@ -698,7 +768,7 @@ impl Repo {
         }
 
         command.args(git_args);
-        log::trace!("Executing git command: {:?}", command);
+        log::trace!("Executing git command: {command:?}");
 
         exec_timeout(
             &mut command,
@@ -1138,6 +1208,40 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_scan_dir_timeout() -> io::Result<()> {
+        let empty = testdir(&[])?;
+        let follow_symlinks = true;
+        let timeout = Duration::new(0, 0);
+        let empty_dc = DirContents::from_path_with_timeout(empty.path(), timeout, follow_symlinks)?;
+
+        assert!(
+            !ScanDir {
+                dir_contents: &empty_dc,
+                files: &["package.json"],
+                extensions: &["js"],
+                folders: &["node_modules"],
+            }
+            .is_match()
+        );
+        empty.close()?;
+
+        let rust = testdir(&["README.md", "Cargo.toml", "src/main.rs"])?;
+        let rust_dc = DirContents::from_path_with_timeout(rust.path(), timeout, follow_symlinks)?;
+        assert!(
+            !ScanDir {
+                dir_contents: &rust_dc,
+                files: &["package.json"],
+                extensions: &["js"],
+                folders: &["node_modules"],
+            }
+            .is_match()
+        );
+        rust.close()?;
+
+        Ok(())
+    }
+
     #[test]
     fn context_constructor_should_canonicalize_current_dir() -> io::Result<()> {
         #[cfg(not(windows))]
@@ -1157,12 +1261,12 @@ mod tests {
         // Mock navigation into the symlink path
         let test_path = path_symlink.join("yyy");
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             test_path.clone(),
             test_path.clone(),
-            Default::default(),
+            Env::default(),
         );
 
         assert_ne!(context.current_dir, context.logical_dir);
@@ -1182,12 +1286,12 @@ mod tests {
         // Mock navigation to a directory which does not exist on disk
         let test_path = Path::new("/path_which_does_not_exist").to_path_buf();
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             test_path.clone(),
             test_path.clone(),
-            Default::default(),
+            Env::default(),
         );
 
         let expected_current_dir = &test_path;
@@ -1204,12 +1308,12 @@ mod tests {
         // Mock navigation to a directory which does not exist on disk
         let test_path = Path::new("~/path_which_does_not_exist").to_path_buf();
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             test_path.clone(),
             test_path.clone(),
-            Default::default(),
+            Env::default(),
         );
 
         let expected_current_dir = home_dir()
