@@ -15,12 +15,13 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     let config: BatteryConfig = BatteryConfig::try_load(module.config);
 
     // Parse config under `display`.
-    // Select the first style that match the threshold,
-    // if all thresholds are lower do not display battery module.
+    // Select the style that is most minimally greater than the current battery percentage.
+    // If no such style exists do not display battery module.
     let display_style = config
         .display
         .iter()
-        .find(|display_style| percentage <= display_style.threshold as f32)?;
+        .filter(|display_style| percentage <= display_style.threshold as f32)
+        .min_by_key(|display_style| display_style.threshold)?;
 
     // Parse the format string and build the module
     match StringFormatter::new(config.format) {
@@ -55,13 +56,13 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
                     Some(module)
                 }
                 Err(e) => {
-                    log::warn!("Cannot parse `battery.format`: {}", e);
+                    log::warn!("Cannot parse `battery.format`: {e}");
                     None
                 }
             }
         }
         Err(e) => {
-            log::warn!("Cannot load `battery.format`: {}", e);
+            log::warn!("Cannot load `battery.format`: {e}");
             None
         }
     }
@@ -69,15 +70,15 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
 
 fn get_battery_status(context: &Context) -> Option<BatteryStatus> {
     let battery_info = context.battery_info_provider.get_battery_info()?;
-    if battery_info.energy_full != 0.0 {
+    if battery_info.energy_full == 0.0 {
+        None
+    } else {
         let battery = BatteryStatus {
             percentage: battery_info.energy / battery_info.energy_full * 100.0,
             state: battery_info.state,
         };
-        log::debug!("Battery status: {:?}", battery);
+        log::debug!("Battery status: {battery:?}");
         Some(battery)
-    } else {
-        None
     }
 }
 
@@ -130,10 +131,13 @@ impl BatteryInfoProvider for BatteryInfoProviderImpl {
             batteries
                 .filter_map(|battery| match battery {
                     Ok(battery) => {
-                        log::debug!("Battery found: {:?}", battery);
+                        log::debug!("Battery found: {battery:?}");
+
+                        let charge_rate = battery.state_of_charge().value;
+                        let energy_full = battery.energy_full().value;
                         Some(BatteryInfo {
-                            energy: battery.energy().value,
-                            energy_full: battery.energy_full().value,
+                            energy: charge_rate * energy_full,
+                            energy_full,
                             state: battery.state(),
                         })
                     }
@@ -413,4 +417,47 @@ mod tests {
 
         assert_eq!(expected, actual);
     }
+
+    #[test]
+    fn battery_expected_style() {
+        let mut mock = MockBatteryInfoProvider::new();
+
+        mock.expect_get_battery_info().times(2).returning(|| {
+            Some(BatteryInfo {
+                energy: 50.0,
+                energy_full: 100.0,
+                state: battery::State::Discharging,
+            })
+        });
+
+        // Larger threshold first
+        let actual = ModuleRenderer::new("battery")
+            .config(toml::toml! {
+                [[battery.display]]
+                threshold = 100
+                style = "red"
+                [[battery.display]]
+                threshold = 60
+                style = "green bold"
+            })
+            .battery_info_provider(&mock)
+            .collect();
+        let expected = Some(format!("{} ", Color::Green.bold().paint("󰂃 50%")));
+        assert_eq!(expected, actual);
+
+        // Smaller threshold first
+        let actual = ModuleRenderer::new("battery")
+            .config(toml::toml! {
+                [[battery.display]]
+                threshold = 60
+                style = "green bold"
+                [[battery.display]]
+                threshold = 100
+                style = "red"
+            })
+            .battery_info_provider(&mock)
+            .collect();
+        let expected = Some(format!("{} ", Color::Green.bold().paint("󰂃 50%")));
+        assert_eq!(expected, actual);
+    }
 }
