@@ -82,7 +82,7 @@ impl RustToolingEnvironmentInfo {
                     })
                     .or_else(|| execute_rustup_default(context));
 
-                log::debug!("Environmental toolchain override is {:?}", out);
+                log::debug!("Environmental toolchain override is {out:?}");
                 out
             })
             .as_deref()
@@ -103,7 +103,7 @@ impl RustToolingEnvironmentInfo {
                             .join("rustc")
                     })
                     .and_then(|rustc| {
-                        log::trace!("Running rustc --version directly with {:?}", rustc);
+                        log::trace!("Running rustc --version directly with {rustc:?}");
                         create_command(rustc).map(|mut cmd| {
                             cmd.arg("--version");
                             cmd
@@ -125,7 +125,7 @@ impl RustToolingEnvironmentInfo {
                 RustupRunRustcVersionOutcome::ToolchainUnknown
             };
 
-            log::debug!("Rustup rustc version is {:?}", out);
+            log::debug!("Rustup rustc version is {out:?}");
             out
         })
     }
@@ -147,7 +147,7 @@ impl RustToolingEnvironmentInfo {
                 let out =
                     format_rustc_version_verbose(std::str::from_utf8(&stdout).ok()?, toolchain);
 
-                log::debug!("Rustup verbose version is {:?}", out);
+                log::debug!("Rustup verbose version is {out:?}");
                 out
             })
             .as_ref()
@@ -195,7 +195,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `rust`:\n{}", error);
+            log::warn!("Error in module `rust`:\n{error}");
             return None;
         }
     });
@@ -332,7 +332,7 @@ fn find_rust_toolchain_file(context: &Context) -> Option<String> {
 
     if context
         .dir_contents()
-        .map_or(false, |dir| dir.has_file("rust-toolchain"))
+        .is_ok_and(|dir| dir.has_file("rust-toolchain"))
     {
         if let Some(toolchain) = read_channel(Path::new("rust-toolchain"), false) {
             return Some(toolchain);
@@ -341,7 +341,7 @@ fn find_rust_toolchain_file(context: &Context) -> Option<String> {
 
     if context
         .dir_contents()
-        .map_or(false, |dir| dir.has_file("rust-toolchain.toml"))
+        .is_ok_and(|dir| dir.has_file("rust-toolchain.toml"))
     {
         if let Some(toolchain) = read_channel(Path::new("rust-toolchain.toml"), true) {
             return Some(toolchain);
@@ -393,7 +393,7 @@ fn format_rustc_version(rustc_version: &str, version_format: &str) -> Option<Str
     match VersionFormatter::format_version(version, version_format) {
         Ok(formatted) => Some(formatted),
         Err(error) => {
-            log::warn!("Error formatting `rust` version:\n{}", error);
+            log::warn!("Error formatting `rust` version:\n{error}");
             Some(format!("v{version}"))
         }
     }
@@ -466,15 +466,14 @@ impl RustupSettings {
 
     fn from_toml_str(toml_str: &str) -> Option<Self> {
         let settings = toml::from_str::<Self>(toml_str).ok()?;
-        match settings.version.as_deref() {
-            Some("12") => Some(settings),
-            _ => {
-                log::warn!(
-                    r#"Rustup settings version is {:?}, expected "12""#,
-                    settings.version
-                );
-                None
-            }
+        if settings.version.as_deref() == Some("12") {
+            Some(settings)
+        } else {
+            log::warn!(
+                r#"Rustup settings version is {:?}, expected "12""#,
+                settings.version
+            );
+            None
         }
     }
 
@@ -499,7 +498,8 @@ impl RustupSettings {
 
 #[cfg(test)]
 mod tests {
-    use crate::context::{Shell, Target};
+    use crate::context::{Properties, Shell, Target};
+    use crate::context_env::Env;
     use std::io;
     use std::process::{ExitStatus, Output};
     use std::sync::LazyLock;
@@ -735,7 +735,7 @@ version = "12"
             Target::Main,
             dir.path().into(),
             dir.path().into(),
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(
@@ -752,12 +752,12 @@ version = "12"
         )?;
 
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             dir.path().into(),
             dir.path().into(),
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(
@@ -779,7 +779,7 @@ version = "12"
             Target::Main,
             dir.path().into(),
             dir.path().into(),
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(
@@ -798,12 +798,12 @@ version = "12"
         )?;
 
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             child_dir_path.clone(),
             child_dir_path,
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(
@@ -819,12 +819,12 @@ version = "12"
         fs::write(dir.path().join("rust-toolchain.toml"), "1.34.0")?;
 
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             dir.path().into(),
             dir.path().into(),
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(find_rust_toolchain_file(&context), None);
@@ -838,12 +838,12 @@ version = "12"
         )?;
 
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             dir.path().into(),
             dir.path().into(),
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(
@@ -860,12 +860,12 @@ version = "12"
         )?;
 
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             dir.path().into(),
             dir.path().into(),
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(
@@ -884,12 +884,12 @@ version = "12"
         )?;
 
         let context = Context::new_with_shell_and_path(
-            Default::default(),
+            Properties::default(),
             Shell::Unknown,
             Target::Main,
             child_dir_path.clone(),
             child_dir_path,
-            Default::default(),
+            Env::default(),
         );
 
         assert_eq!(
